@@ -10,8 +10,8 @@ test_that("check_nrow requires a data frame", {
 test_that("check_nrow requires counts", {
   x <- data.frame(y = 2)
   expect_identical(check_nrow(x), x)
-  expect_error(check_nrow(x, nrow = -1), "nrow must be one or two counts")
-  expect_error(check_nrow(x, nrow = 1.5), "nrow must be one or two counts")
+  expect_error(check_nrow(x, nrow = -1), "nrow must be a flag, a missing value, a count or a count range")
+  expect_error(check_nrow(x, nrow = 1.5), "nrow must be a flag, a missing value, a count or a count range")
 })
 
 test_that("check_nrow checks nrow", {
